# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_sma.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/tick_analytics/v1/tick_sma.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xa4\x03\n\x0eTickSmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x45\n\x05\x66ield\x18\x03 \x01(\x0e\x32\x36.systemathics.apis.services.tick_analytics.v1.SmaPrice\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12)\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08sampling\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\x08 \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\t \x03(\t\x12\x0e\n\x06reject\x18\n \x03(\t\"\x7f\n\x0fTickSmaResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12-\n\x07\x61verage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue*`\n\x08SmaPrice\x12\x19\n\x15SMA_PRICE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSMA_PRICE_TRADE\x10\x01\x12\x11\n\rSMA_PRICE_BID\x10\x02\x12\x11\n\rSMA_PRICE_ASK\x10\x03\x32\x9b\x01\n\x0eTickSmaService\x12\x88\x01\n\x07TickSma\x12<.systemathics.apis.services.tick_analytics.v1.TickSmaRequest\x1a=.systemathics.apis.services.tick_analytics.v1.TickSmaResponse0\x01\x62\x06proto3')

_SMAPRICE = DESCRIPTOR.enum_types_by_name['SmaPrice']
SmaPrice = enum_type_wrapper.EnumTypeWrapper(_SMAPRICE)
SMA_PRICE_UNSPECIFIED = 0
SMA_PRICE_TRADE = 1
SMA_PRICE_BID = 2
SMA_PRICE_ASK = 3


_TICKSMAREQUEST = DESCRIPTOR.message_types_by_name['TickSmaRequest']
_TICKSMARESPONSE = DESCRIPTOR.message_types_by_name['TickSmaResponse']
TickSmaRequest = _reflection.GeneratedProtocolMessageType('TickSmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKSMAREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickSmaRequest)
  })
_sym_db.RegisterMessage(TickSmaRequest)

TickSmaResponse = _reflection.GeneratedProtocolMessageType('TickSmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKSMARESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickSmaResponse)
  })
_sym_db.RegisterMessage(TickSmaResponse)

_TICKSMASERVICE = DESCRIPTOR.services_by_name['TickSmaService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SMAPRICE._serialized_start=861
  _SMAPRICE._serialized_end=957
  _TICKSMAREQUEST._serialized_start=310
  _TICKSMAREQUEST._serialized_end=730
  _TICKSMARESPONSE._serialized_start=732
  _TICKSMARESPONSE._serialized_end=859
  _TICKSMASERVICE._serialized_start=960
  _TICKSMASERVICE._serialized_end=1115
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_trade_conditions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHsystemathics/apis/services/tick_analytics/v1/tick_trade_conditions.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xa5\x02\n\x1aTickTradeConditionsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12+\n\x08sampling\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xc0\x01\n\x1bTickTradeConditionsResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06volume\x18\x02 \x01(\x03\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\x12R\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x44.systemathics.apis.services.tick_analytics.v1.TickTradeConditionData\"u\n\x16TickTradeConditionData\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\x12\n\npercentage\x18\x03 \x01(\x01\x12\x0e\n\x06volume\x18\x04 \x01(\x03\x12\x19\n\x11volume_percentage\x18\x05 \x01(\x01\x32\xcb\x01\n\x1aTickTradeConditionsService\x12\xac\x01\n\x13TickTradeConditions\x12H.systemathics.apis.services.tick_analytics.v1.TickTradeConditionsRequest\x1aI.systemathics.apis.services.tick_analytics.v1.TickTradeConditionsResponse0\x01\x62\x06proto3')



_TICKTRADECONDITIONSREQUEST = DESCRIPTOR.message_types_by_name['TickTradeConditionsRequest']
_TICKTRADECONDITIONSRESPONSE = DESCRIPTOR.message_types_by_name['TickTradeConditionsResponse']
_TICKTRADECONDITIONDATA = DESCRIPTOR.message_types_by_name['TickTradeConditionData']
TickTradeConditionsRequest = _reflection.GeneratedProtocolMessageType('TickTradeConditionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionsRequest)
  })
_sym_db.RegisterMessage(TickTradeConditionsRequest)

TickTradeConditionsResponse = _reflection.GeneratedProtocolMessageType('TickTradeConditionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionsResponse)
  })
_sym_db.RegisterMessage(TickTradeConditionsResponse)

TickTradeConditionData = _reflection.GeneratedProtocolMessageType('TickTradeConditionData', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONDATA,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionData)
  })
_sym_db.RegisterMessage(TickTradeConditionData)

_TICKTRADECONDITIONSSERVICE = DESCRIPTOR.services_by_name['TickTradeConditionsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKTRADECONDITIONSREQUEST._serialized_start=291
  _TICKTRADECONDITIONSREQUEST._serialized_end=584
  _TICKTRADECONDITIONSRESPONSE._serialized_start=587
  _TICKTRADECONDITIONSRESPONSE._serialized_end=779
  _TICKTRADECONDITIONDATA._serialized_start=781
  _TICKTRADECONDITIONDATA._serialized_end=898
  _TICKTRADECONDITIONSSERVICE._serialized_start=901
  _TICKTRADECONDITIONSSERVICE._serialized_end=1104
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_bollinger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAsystemathics/apis/services/tick_analytics/v1/tick_bollinger.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xc3\x03\n\x14TickBollingerRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12K\n\x05\x66ield\x18\x03 \x01(\x0e\x32<.systemathics.apis.services.tick_analytics.v1.BollingerPrice\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x11\n\tdeviation\x18\x05 \x01(\x01\x12)\n\x06period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08sampling\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\t \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\n \x03(\t\x12\x0e\n\x06reject\x18\x0b \x03(\t\"\xde\x01\n\x15TickBollingerResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12+\n\x05lower\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05upper\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06middle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue*~\n\x0e\x42ollingerPrice\x12\x1f\n\x1b\x42OLLINGER_PRICE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x42OLLINGER_PRICE_TRADE\x10\x01\x12\x17\n\x13\x42OLLINGER_PRICE_BID\x10\x02\x12\x17\n\x13\x42OLLINGER_PRICE_ASK\x10\x03\x32\xb3\x01\n\x14TickBollingerService\x12\x9a\x01\n\rTickBollinger\x12\x42.systemathics.apis.services.tick_analytics.v1.TickBollingerRequest\x1a\x43.systemathics.apis.services.tick_analytics.v1.TickBollingerResponse0\x01\x62\x06proto3')

_BOLLINGERPRICE = DESCRIPTOR.enum_types_by_name['BollingerPrice']
BollingerPrice = enum_type_wrapper.EnumTypeWrapper(_BOLLINGERPRICE)
BOLLINGER_PRICE_UNSPECIFIED = 0
BOLLINGER_PRICE_TRADE = 1
BOLLINGER_PRICE_BID = 2
BOLLINGER_PRICE_ASK = 3


_TICKBOLLINGERREQUEST = DESCRIPTOR.message_types_by_name['TickBollingerRequest']
_TICKBOLLINGERRESPONSE = DESCRIPTOR.message_types_by_name['TickBollingerResponse']
TickBollingerRequest = _reflection.GeneratedProtocolMessageType('TickBollingerRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOLLINGERREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBollingerRequest)
  })
_sym_db.RegisterMessage(TickBollingerRequest)

TickBollingerResponse = _reflection.GeneratedProtocolMessageType('TickBollingerResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOLLINGERRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBollingerResponse)
  })
_sym_db.RegisterMessage(TickBollingerResponse)

_TICKBOLLINGERSERVICE = DESCRIPTOR.services_by_name['TickBollingerService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BOLLINGERPRICE._serialized_start=994
  _BOLLINGERPRICE._serialized_end=1120
  _TICKBOLLINGERREQUEST._serialized_start=316
  _TICKBOLLINGERREQUEST._serialized_end=767
  _TICKBOLLINGERRESPONSE._serialized_start=770
  _TICKBOLLINGERRESPONSE._serialized_end=992
  _TICKBOLLINGERSERVICE._serialized_start=1123
  _TICKBOLLINGERSERVICE._serialized_end=1302
# @@protoc_insertion_point(module_scope)



"""Systemathics Ganymede APIs Token Helpers

This module helps to create channels to access Systemathics Ganymede authenticated APIs.

functions:
    * get_grpc_channel - Get a channel suitable to call Ganymede gRPC APIs.
    * get_aio_grpc_channel - Get an aio channel suitable to call Ganymede gRPC APIs.
"""

import os
from shutil import ExecError
import grpc

DEFAULT_ENDPOINT = "https://grpc.ganymede.cloud"

def get_grpc_channel() -> grpc.Channel:
    """
    Get a channel suitable to call Ganymede gRPC APIs.
    This uses the GRPC_APIS environment variable in the form http[s]://fdqn[:port] (if no scheme is give, we'll assume https).
    If none is detected, use DEFAULT_ENDPOINT.
    Note:
        For secure channels, we'll try to guess the path of CA certificates chain automatically.
        For windows you need to 'pip install wheel python-certifi-win32' for that to work (it exports Windows CA Store to a PEM file).
        In the event CA certificates cannot be found, or if you want to use a custom file, set the SSL_CERT_FILE environment variable.
    Returns:
        An aio channel suitable to call Ganymede gRPC APIs.
    """
    endpoint = os.getenv('GRPC_APIS','')
    endpoint = endpoint if endpoint else DEFAULT_ENDPOINT # if no endpoint was provided, use the default one
    endpoint = endpoint if endpoint.startswith("http") else f"https://{endpoint}" # if no scheme was provided, assume it's https
    if (endpoint.startswith("https")):
        return grpc.secure_channel(endpoint.replace("https://",""), _get_channel_credentials())
    else:
        return grpc.insecure_channel(endpoint.replace("http://",""))

def get_aio_grpc_channel() -> grpc.aio.Channel:
    """
    Get an aio channel suitable to call Ganymede gRPC APIs.
    This uses the GRPC_APIS environment variable in the form http[s]://fdqn[:port].
    If none is detected, use DEFAULT_ENDPOINT.
    Note:
        For secure channels, we'll try to guess the path of CA certificates chain automatically.
        For windows you need to 'pip install wheel python-certifi-win32' for that to work (it exports Windows CA Store to a PEM file).
        In the event CA certificates cannot be found, or if you want to use a custom file, set the SSL_CERT_FILE environment variable.
    Returns:
        An aio channel suitable to call Ganymede gRPC APIs.
    """
    endpoint = os.getenv('GRPC_APIS','')
    endpoint = endpoint if endpoint else DEFAULT_ENDPOINT # if no endpoint was provided, use the default one
    endpoint = endpoint if endpoint.startswith("http") else f"https://{endpoint}" # if no scheme was provided, assume it's https
    if (endpoint.startswith("https")):
        return grpc.aio.secure_channel(endpoint.replace("https://",""), _get_channel_credentials())
    else:
        return grpc.aio.insecure_channel(endpoint.replace("http://",""))

def _get_channel_credentials() -> grpc.ChannelCredentials:
    # If we have a SSL_CERT_FILE env variable, use it
    ssl_cert_file = os.getenv('SSL_CERT_FILE','')
    if (ssl_cert_file !='' ):
        if (not(os.path.isfile(ssl_cert_file))):
            print(f"warn: Found SSL_CERT_FILE={ssl_cert_file} environment variable, but file doesn't exist!")
        cabundle = ssl_cert_file
    # Otherwise try autodetection
    else:
        cabundle = _autodetect_ca_bundle()

    with open(cabundle, 'rb') as f:
        credentials = grpc.ssl_channel_credentials(f.read())
        return credentials

def _autodetect_ca_bundle() -> str:
    cabundles = [
	"/etc/ssl/certs/ca-certificates.crt",                                  # Debian/Ubuntu/Gentoo/etc..
	"/etc/pki/tls/certs/ca-bundle.crt",                                    # Fedora/RHEL 6
	"/etc/ssl/ca-bundle.pem",                                              # OpenSUSE
	"/etc/pki/tls/cacert.pem",                                             # OpenELEC
	"/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem",                   # CentOS/RHEL 7
	"/etc/ssl/cert.pem",                                                   # Alpine Linux
    os.path.join(os.getenv('LOCALAPPDATA',''), '.certifi', 'cacert.pem')   # Windows (requires: pip install wheel python-certifi-win32)
    ]

    for cabundle in cabundles:
        if (os.path.isfile(cabundle)):
            return cabundle

    raise Exception(f"Could not auto detect trusted root certificates file, tried {cabundles}. Please help by setting SSL_CERT_FILE environment variable")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/trade.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/trade.proto\x12 systemathics.apis.type.shared.v1\"C\n\x05Trade\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x11\n\tcondition\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\tb\x06proto3')



_TRADE = DESCRIPTOR.message_types_by_name['Trade']
Trade = _reflection.GeneratedProtocolMessageType('Trade', (_message.Message,), {
  'DESCRIPTOR' : _TRADE,
  '__module__' : 'systemathics.apis.type.shared.v1.trade_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Trade)
  })
_sym_db.RegisterMessage(Trade)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRADE._serialized_start=82
  _TRADE._serialized_end=149
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/changes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/corporate_actions/v1/changes.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x96\x01\n\x0e\x43hangesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"X\n\x0f\x43hangesResponse\x12\x45\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x37.systemathics.apis.services.corporate_actions.v1.Change\"`\n\x06\x43hange\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x12\n\nnew_symbol\x18\x02 \x01(\t\x12\x12\n\nold_symbol\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x9f\x01\n\x0e\x43hangesService\x12\x8c\x01\n\x07\x43hanges\x12?.systemathics.apis.services.corporate_actions.v1.ChangesRequest\x1a@.systemathics.apis.services.corporate_actions.v1.ChangesResponseb\x06proto3')



_CHANGESREQUEST = DESCRIPTOR.message_types_by_name['ChangesRequest']
_CHANGESRESPONSE = DESCRIPTOR.message_types_by_name['ChangesResponse']
_CHANGE = DESCRIPTOR.message_types_by_name['Change']
ChangesRequest = _reflection.GeneratedProtocolMessageType('ChangesRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGESREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.ChangesRequest)
  })
_sym_db.RegisterMessage(ChangesRequest)

ChangesResponse = _reflection.GeneratedProtocolMessageType('ChangesResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGESRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.ChangesResponse)
  })
_sym_db.RegisterMessage(ChangesResponse)

Change = _reflection.GeneratedProtocolMessageType('Change', (_message.Message,), {
  'DESCRIPTOR' : _CHANGE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.changes_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Change)
  })
_sym_db.RegisterMessage(Change)

_CHANGESSERVICE = DESCRIPTOR.services_by_name['ChangesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANGESREQUEST._serialized_start=242
  _CHANGESREQUEST._serialized_end=392
  _CHANGESRESPONSE._serialized_start=394
  _CHANGESRESPONSE._serialized_end=482
  _CHANGE._serialized_start=484
  _CHANGE._serialized_end=580
  _CHANGESSERVICE._serialized_start=583
  _CHANGESSERVICE._serialized_end=742
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/quotes_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import quote_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_quote__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/type/shared/v1/quotes_data.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a,systemathics/apis/type/shared/v1/quote.proto\"\x86\x01\n\nQuotesData\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x06quotes\x18\x03 \x03(\x0b\x32\'.systemathics.apis.type.shared.v1.Quoteb\x06proto3')



_QUOTESDATA = DESCRIPTOR.message_types_by_name['QuotesData']
QuotesData = _reflection.GeneratedProtocolMessageType('QuotesData', (_message.Message,), {
  'DESCRIPTOR' : _QUOTESDATA,
  '__module__' : 'systemathics.apis.type.shared.v1.quotes_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.QuotesData)
  })
_sym_db.RegisterMessage(QuotesData)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUOTESDATA._serialized_start=168
  _QUOTESDATA._serialized_end=302
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/date_interval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/type/shared/v1/date_interval.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\"Z\n\x0c\x44\x61teInterval\x12%\n\nstart_date\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12#\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x11.google.type.Dateb\x06proto3')



_DATEINTERVAL = DESCRIPTOR.message_types_by_name['DateInterval']
DateInterval = _reflection.GeneratedProtocolMessageType('DateInterval', (_message.Message,), {
  'DESCRIPTOR' : _DATEINTERVAL,
  '__module__' : 'systemathics.apis.type.shared.v1.date_interval_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.DateInterval)
  })
_sym_db.RegisterMessage(DateInterval)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATEINTERVAL._serialized_start=114
  _DATEINTERVAL._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xbb\x04\n\x11StaticDataRequest\x12H\n\nasset_type\x18\x01 \x01(\x0e\x32\x34.systemathics.apis.services.static_data.v1.AssetType\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65xchange\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06ticker\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x66uture_contract\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x66uture_category\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\requity_sector\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05index\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x63ode\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x05start\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12*\n\x05\x63ount\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xb2\x02\n\x12StaticDataResponse\x12G\n\x07\x66utures\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntry\x12H\n\x08\x65quities\x18\x02 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntry\x12\x41\n\x04\x65tfs\x18\x03 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.EtfEntry\x12\x46\n\x07indices\x18\x04 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.IndexEntry\"\x8b\x05\n\x0b\x45quityEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12T\n\x07mapping\x18\x08 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x0c\n\x04isin\x18\x0f \x01(\t\x12\r\n\x05\x63usip\x18\x10 \x01(\t\x12\r\n\x05sedol\x18\x11 \x01(\t\x12T\n\x07sectors\x18\x12 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry\x12\x34\n\x0e\x63\x61pitalization\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cSectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x05\n\x08\x45tfEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12Q\n\x07mapping\x18\x08 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x0c\n\x04isin\x18\x0f \x01(\t\x12\r\n\x05\x63usip\x18\x10 \x01(\t\x12\r\n\x05sedol\x18\x11 \x01(\t\x12Q\n\x07sectors\x18\x12 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry\x12\x34\n\x0e\x63\x61pitalization\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cSectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x05\n\x0b\x46utureEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12T\n\x07mapping\x18\x08 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x12\n\nunderlying\x18\x0f \x01(\t\x12\x10\n\x08\x63ontract\x18\x10 \x01(\t\x12V\n\x08\x63\x61tegory\x18\x11 \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry\x12\r\n\x05\x63hain\x18\x12 \x01(\t\x12#\n\x08maturity\x18\x13 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05month\x18\x14 \x01(\t\x12\x0c\n\x04year\x18\x15 \x01(\x05\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rCategoryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x03\n\nIndexEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12S\n\x07mapping\x18\x08 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x0f \x01(\t\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*\x93\x01\n\tAssetType\x12\x1a\n\x16\x41SSET_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41SSET_TYPE_ALL\x10\x01\x12\x15\n\x11\x41SSET_TYPE_EQUITY\x10\x02\x12\x15\n\x11\x41SSET_TYPE_FUTURE\x10\x03\x12\x12\n\x0e\x41SSET_TYPE_ETF\x10\x04\x12\x14\n\x10\x41SSET_TYPE_INDEX\x10\x05\x32\x9f\x01\n\x11StaticDataService\x12\x89\x01\n\nStaticData\x12<.systemathics.apis.services.static_data.v1.StaticDataRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponseb\x06proto3')

_ASSETTYPE = DESCRIPTOR.enum_types_by_name['AssetType']
AssetType = enum_type_wrapper.EnumTypeWrapper(_ASSETTYPE)
ASSET_TYPE_UNSPECIFIED = 0
ASSET_TYPE_ALL = 1
ASSET_TYPE_EQUITY = 2
ASSET_TYPE_FUTURE = 3
ASSET_TYPE_ETF = 4
ASSET_TYPE_INDEX = 5


_STATICDATAREQUEST = DESCRIPTOR.message_types_by_name['StaticDataRequest']
_STATICDATARESPONSE = DESCRIPTOR.message_types_by_name['StaticDataResponse']
_EQUITYENTRY = DESCRIPTOR.message_types_by_name['EquityEntry']
_EQUITYENTRY_MAPPINGENTRY = _EQUITYENTRY.nested_types_by_name['MappingEntry']
_EQUITYENTRY_SECTORSENTRY = _EQUITYENTRY.nested_types_by_name['SectorsEntry']
_ETFENTRY = DESCRIPTOR.message_types_by_name['EtfEntry']
_ETFENTRY_MAPPINGENTRY = _ETFENTRY.nested_types_by_name['MappingEntry']
_ETFENTRY_SECTORSENTRY = _ETFENTRY.nested_types_by_name['SectorsEntry']
_FUTUREENTRY = DESCRIPTOR.message_types_by_name['FutureEntry']
_FUTUREENTRY_MAPPINGENTRY = _FUTUREENTRY.nested_types_by_name['MappingEntry']
_FUTUREENTRY_CATEGORYENTRY = _FUTUREENTRY.nested_types_by_name['CategoryEntry']
_INDEXENTRY = DESCRIPTOR.message_types_by_name['IndexEntry']
_INDEXENTRY_MAPPINGENTRY = _INDEXENTRY.nested_types_by_name['MappingEntry']
StaticDataRequest = _reflection.GeneratedProtocolMessageType('StaticDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATICDATAREQUEST,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticDataRequest)
  })
_sym_db.RegisterMessage(StaticDataRequest)

StaticDataResponse = _reflection.GeneratedProtocolMessageType('StaticDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATICDATARESPONSE,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticDataResponse)
  })
_sym_db.RegisterMessage(StaticDataResponse)

EquityEntry = _reflection.GeneratedProtocolMessageType('EquityEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _EQUITYENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry)
    })
  ,

  'SectorsEntry' : _reflection.GeneratedProtocolMessageType('SectorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EQUITYENTRY_SECTORSENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry)
    })
  ,
  'DESCRIPTOR' : _EQUITYENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry)
  })
_sym_db.RegisterMessage(EquityEntry)
_sym_db.RegisterMessage(EquityEntry.MappingEntry)
_sym_db.RegisterMessage(EquityEntry.SectorsEntry)

EtfEntry = _reflection.GeneratedProtocolMessageType('EtfEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _ETFENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry)
    })
  ,

  'SectorsEntry' : _reflection.GeneratedProtocolMessageType('SectorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ETFENTRY_SECTORSENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry)
    })
  ,
  'DESCRIPTOR' : _ETFENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry)
  })
_sym_db.RegisterMessage(EtfEntry)
_sym_db.RegisterMessage(EtfEntry.MappingEntry)
_sym_db.RegisterMessage(EtfEntry.SectorsEntry)

FutureEntry = _reflection.GeneratedProtocolMessageType('FutureEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _FUTUREENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry)
    })
  ,

  'CategoryEntry' : _reflection.GeneratedProtocolMessageType('CategoryEntry', (_message.Message,), {
    'DESCRIPTOR' : _FUTUREENTRY_CATEGORYENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry)
    })
  ,
  'DESCRIPTOR' : _FUTUREENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry)
  })
_sym_db.RegisterMessage(FutureEntry)
_sym_db.RegisterMessage(FutureEntry.MappingEntry)
_sym_db.RegisterMessage(FutureEntry.CategoryEntry)

IndexEntry = _reflection.GeneratedProtocolMessageType('IndexEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _INDEXENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry)
    })
  ,
  'DESCRIPTOR' : _INDEXENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.IndexEntry)
  })
_sym_db.RegisterMessage(IndexEntry)
_sym_db.RegisterMessage(IndexEntry.MappingEntry)

_STATICDATASERVICE = DESCRIPTOR.services_by_name['StaticDataService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EQUITYENTRY_MAPPINGENTRY._options = None
  _EQUITYENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _EQUITYENTRY_SECTORSENTRY._options = None
  _EQUITYENTRY_SECTORSENTRY._serialized_options = b'8\001'
  _ETFENTRY_MAPPINGENTRY._options = None
  _ETFENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _ETFENTRY_SECTORSENTRY._options = None
  _ETFENTRY_SECTORSENTRY._serialized_options = b'8\001'
  _FUTUREENTRY_MAPPINGENTRY._options = None
  _FUTUREENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _FUTUREENTRY_CATEGORYENTRY._options = None
  _FUTUREENTRY_CATEGORYENTRY._serialized_options = b'8\001'
  _INDEXENTRY_MAPPINGENTRY._options = None
  _INDEXENTRY_MAPPINGENTRY._serialized_options = b'8\001'
  _ASSETTYPE._serialized_start=3515
  _ASSETTYPE._serialized_end=3662
  _STATICDATAREQUEST._serialized_start=214
  _STATICDATAREQUEST._serialized_end=785
  _STATICDATARESPONSE._serialized_start=788
  _STATICDATARESPONSE._serialized_end=1094
  _EQUITYENTRY._serialized_start=1097
  _EQUITYENTRY._serialized_end=1748
  _EQUITYENTRY_MAPPINGENTRY._serialized_start=1654
  _EQUITYENTRY_MAPPINGENTRY._serialized_end=1700
  _EQUITYENTRY_SECTORSENTRY._serialized_start=1702
  _EQUITYENTRY_SECTORSENTRY._serialized_end=1748
  _ETFENTRY._serialized_start=1751
  _ETFENTRY._serialized_end=2393
  _ETFENTRY_MAPPINGENTRY._serialized_start=1654
  _ETFENTRY_MAPPINGENTRY._serialized_end=1700
  _ETFENTRY_SECTORSENTRY._serialized_start=1702
  _ETFENTRY_SECTORSENTRY._serialized_end=1748
  _FUTUREENTRY._serialized_start=2396
  _FUTUREENTRY._serialized_end=3071
  _FUTUREENTRY_MAPPINGENTRY._serialized_start=1654
  _FUTUREENTRY_MAPPINGENTRY._serialized_end=1700
  _FUTUREENTRY_CATEGORYENTRY._serialized_start=3024
  _FUTUREENTRY_CATEGORYENTRY._serialized_end=3071
  _INDEXENTRY._serialized_start=3074
  _INDEXENTRY._serialized_end=3512
  _INDEXENTRY_MAPPINGENTRY._serialized_start=1654
  _INDEXENTRY_MAPPINGENTRY._serialized_end=1700
  _STATICDATASERVICE._serialized_start=3665
  _STATICDATASERVICE._serialized_end=3824
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v1/intraday_vwap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:systemathics/apis/services/intraday/v1/intraday_vwap.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xee\x01\n\x14IntradayVwapsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"[\n\x15IntradayVwapsResponse\x12\x42\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.services.intraday.v1.IntradayVwap\"l\n\x0cIntradayVwap\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\xa5\x01\n\x14IntradayVwapsService\x12\x8c\x01\n\rIntradayVwaps\x12<.systemathics.apis.services.intraday.v1.IntradayVwapsRequest\x1a=.systemathics.apis.services.intraday.v1.IntradayVwapsResponseb\x06proto3')



_INTRADAYVWAPSREQUEST = DESCRIPTOR.message_types_by_name['IntradayVwapsRequest']
_INTRADAYVWAPSRESPONSE = DESCRIPTOR.message_types_by_name['IntradayVwapsResponse']
_INTRADAYVWAP = DESCRIPTOR.message_types_by_name['IntradayVwap']
IntradayVwapsRequest = _reflection.GeneratedProtocolMessageType('IntradayVwapsRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVWAPSREQUEST,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayVwapsRequest)
  })
_sym_db.RegisterMessage(IntradayVwapsRequest)

IntradayVwapsResponse = _reflection.GeneratedProtocolMessageType('IntradayVwapsResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVWAPSRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayVwapsResponse)
  })
_sym_db.RegisterMessage(IntradayVwapsResponse)

IntradayVwap = _reflection.GeneratedProtocolMessageType('IntradayVwap', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVWAP,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayVwap)
  })
_sym_db.RegisterMessage(IntradayVwap)

_INTRADAYVWAPSSERVICE = DESCRIPTOR.services_by_name['IntradayVwapsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYVWAPSREQUEST._serialized_start=288
  _INTRADAYVWAPSREQUEST._serialized_end=526
  _INTRADAYVWAPSRESPONSE._serialized_start=528
  _INTRADAYVWAPSRESPONSE._serialized_end=619
  _INTRADAYVWAP._serialized_start=621
  _INTRADAYVWAP._serialized_end=729
  _INTRADAYVWAPSSERVICE._serialized_start=732
  _INTRADAYVWAPSSERVICE._serialized_end=897
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/memo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+systemathics/apis/type/shared/v1/memo.proto\x12 systemathics.apis.type.shared.v1\"G\n\x04Memo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0e\n\x06stream\x18\x03 \x01(\t\x12\x0e\n\x06ticker\x18\x04 \x01(\tb\x06proto3')



_MEMO = DESCRIPTOR.message_types_by_name['Memo']
Memo = _reflection.GeneratedProtocolMessageType('Memo', (_message.Message,), {
  'DESCRIPTOR' : _MEMO,
  '__module__' : 'systemathics.apis.type.shared.v1.memo_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Memo)
  })
_sym_db.RegisterMessage(Memo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEMO._serialized_start=81
  _MEMO._serialized_end=152
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_cma.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_cma.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xec\x01\n\x12IntradayCmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"f\n\x13IntradayCmaResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayCmaData\"a\n\x0fIntradayCmaData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0f\n\x07\x61verage\x18\x03 \x01(\x01\x32\xb1\x01\n\x12IntradayCmaService\x12\x9a\x01\n\x0bIntradayCma\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayCmaRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayCmaResponseb\x06proto3')



_INTRADAYCMAREQUEST = DESCRIPTOR.message_types_by_name['IntradayCmaRequest']
_INTRADAYCMARESPONSE = DESCRIPTOR.message_types_by_name['IntradayCmaResponse']
_INTRADAYCMADATA = DESCRIPTOR.message_types_by_name['IntradayCmaData']
IntradayCmaRequest = _reflection.GeneratedProtocolMessageType('IntradayCmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYCMAREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayCmaRequest)
  })
_sym_db.RegisterMessage(IntradayCmaRequest)

IntradayCmaResponse = _reflection.GeneratedProtocolMessageType('IntradayCmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYCMARESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayCmaResponse)
  })
_sym_db.RegisterMessage(IntradayCmaResponse)

IntradayCmaData = _reflection.GeneratedProtocolMessageType('IntradayCmaData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYCMADATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayCmaData)
  })
_sym_db.RegisterMessage(IntradayCmaData)

_INTRADAYCMASERVICE = DESCRIPTOR.services_by_name['IntradayCmaService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYCMAREQUEST._serialized_start=339
  _INTRADAYCMAREQUEST._serialized_end=575
  _INTRADAYCMARESPONSE._serialized_start=577
  _INTRADAYCMARESPONSE._serialized_end=679
  _INTRADAYCMADATA._serialized_start=681
  _INTRADAYCMADATA._serialized_end=778
  _INTRADAYCMASERVICE._serialized_start=781
  _INTRADAYCMASERVICE._serialized_end=958
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import limit_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_limit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+systemathics/apis/type/shared/v1/book.proto\x12 systemathics.apis.type.shared.v1\x1a,systemathics/apis/type/shared/v1/limit.proto\"r\n\x04\x42ook\x12\x34\n\x03\x62id\x18\x01 \x03(\x0b\x32\'.systemathics.apis.type.shared.v1.Limit\x12\x34\n\x03\x61sk\x18\x02 \x03(\x0b\x32\'.systemathics.apis.type.shared.v1.Limitb\x06proto3')



_BOOK = DESCRIPTOR.message_types_by_name['Book']
Book = _reflection.GeneratedProtocolMessageType('Book', (_message.Message,), {
  'DESCRIPTOR' : _BOOK,
  '__module__' : 'systemathics.apis.type.shared.v1.book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Book)
  })
_sym_db.RegisterMessage(Book)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BOOK._serialized_start=127
  _BOOK._serialized_end=241
# @@protoc_insertion_point(module_scope)
